Use the IMF availability endpoint to return the codes that remain valid for a dimension, optionally constrained by selections for other dimensions.
Usage
list_dimension_values(
dataflow,
dimension,
filters = list(),
agency_id = "IMF.STA",
version = "+"
)Examples
# \donttest{
list_dimension_values(
"CPI",
"FREQUENCY",
filters = list(COUNTRY = "USA")
)
#> # A tibble: 3 × 3
#> code name description
#> <chr> <chr> <chr>
#> 1 A NA NA
#> 2 M NA NA
#> 3 Q NA NA
# }